@@ -23,20 +23,19 @@ try:
 except ModuleNotFoundError:
     from myst_parser.config.main import MdParserConfig
     from myst_parser.mdit_to_docutils.base import make_document
-    from myst_parser.mdit_to_docutils.sphinx_ import SphinxRenderer
+    from myst_parser.mdit_to_docutils.sphinx_ import DocutilsRenderer
     from myst_parser.parsers.mdit import create_md_parser
 
     # to_docutils was removed in myst-parser>=0.18.
     def to_docutils(text):
         # Code is similar to MystParser.parse and myst_parser.parsers.docutils_.Parser.parse.
-        parser = create_md_parser(MdParserConfig(), SphinxRenderer)
+        parser = create_md_parser(MdParserConfig(), DocutilsRenderer)
         parser.options["document"] = make_document()
         return parser.render(text)
 
 
-class CustomJsonrefLoader(jsonref.JsonLoader):
-    def get_remote_json(self, uri, **kwargs):
-        return {}
+def custom_jsonref_jsonloader(uri, **kwargs):
+    return {}
 
 
 class JSONSchemaDirective(Directive):
@@ -186,8 +185,8 @@ class JSONSchemaDirective(Directive):
                 if ref:
                     # just use the name at the end of the ref
                     ref = ref.split('/')[-1]
-                    reference = nodes.reference('', '', nodes.Text(ref), internal=False, refuri='#' + ref.lower(),
-                                                anchorname='')
+                    reference = nodes.reference('', '', nodes.Text(ref), internal=False,
+                                                refuri='#' + nodes.make_id(ref), anchorname='')
                     cell += nodes.paragraph('', nodes.Text('\n\nSee '), reference)
                 if prop.deprecated:
                     cell += nodes.paragraph('', nodes.Text('This property was deprecated in version {}'
@@ -246,13 +245,13 @@ class JSONSchema(object):
     def load(cls, reader, allow_external_refs=False, base_uri=""):
         args = {}
         if not allow_external_refs:
-            args['loader'] = CustomJsonrefLoader()
+            args['loader'] = custom_jsonref_jsonloader
         obj = jsonref.load(reader, object_pairs_hook=OrderedDict, base_uri=base_uri, **args)
         return cls.instantiate(None, obj)
 
     @classmethod
     def loads(cls, string):
-        obj = jsonref.loads(string, object_pairs_hook=OrderedDict, loader=CustomJsonrefLoader())
+        obj = jsonref.loads(string, object_pairs_hook=OrderedDict, loader=custom_jsonref_jsonloader)
         return cls.instantiate(None, obj)
 
     @classmethod
